@@ -4,7 +4,7 @@
 // Alexander Strasser <eclipse7@gmx.net>
 // Sebastian Krmer <mplayer@skraemer.de>
 
-// In synch with rev 1.221
+// In synch with rev 1.237
 
 // ========================= MPlayer help ===========================
 
@@ -65,7 +65,6 @@ static char help_text[]=
 #define MSGTR_NoHomeDir "Kann Homeverzeichnis nicht finden.\n"
 #define MSGTR_GetpathProblem "get_path(\"config\") fehlgeschlagen.\n"
 #define MSGTR_CreatingCfgFile "Erstelle Konfigurationsdatei: %s\n"
-#define MSGTR_InvalidAOdriver "Ungltiger Audioausgabetreibername: %s\nBenutze '-vo help' fr eine Liste der verfgbaren Audiotreiber.\n"
 #define MSGTR_CopyCodecsConf "(Kopiere/verlinke etc/codecs.conf aus dem MPlayer-Quelltext nach ~/.mplayer/codecs.conf)\n"
 #define MSGTR_BuiltinCodecsConf "Benutze eingebaute Standardwerte fr codecs.conf.\n"
 #define MSGTR_CantLoadFont "Kann Schriftdatei nicht laden: %s\n"
@@ -210,26 +209,43 @@ static char help_text[]=
 #define MSGTR_OSDunknown "unbekannt"
 #define MSGTR_OSDDVDNAV "DVDNAV: %s"
 #define MSGTR_OSDChannel "Kanal: %s"
-#define MSGTR_OSDSubtitles "Untertitel: %s"
-#define MSGTR_OSDSubtitlesOff "Untertitel: deaktiviert"
-#define MSGTR_OSDSubtitlesLanguage "Untertitelsprache: (%d) %s"
-#define MSGTR_OSDSub "Untertitel: (%d) %s%s"
 #define MSGTR_OSDSubDelay "Untertitelverzgerung: %dms"
-#define MSGTR_OSDSubPosition "Untertitelposition: %d/100"
-#define MSGTR_OSDSubAlignment "Untertitelausrichtung: %s"
-#define MSGTR_OSDAVDelay "A/V-Verzgerung: %dms"
-#define MSGTR_OSDSpeed "Geschwindigkeit: %6.2f-fach"
-#define MSGTR_OSDStayOnTop "Immer im Vordergrund: %s"
-#define MSGTR_OSDRootwin "Anzeige auf dem Desktop: %s"
-#define MSGTR_OSDBorder "Rand: %s"
-#define MSGTR_OSDFramedrop "Framedropping: %s"
-#define MSGTR_OSDFramedropOn "an"
-#define MSGTR_OSDFramedropHard "hart"
-#define MSGTR_OSDFramedropOff "aus"
+#define MSGTR_OSDSpeed "Geschwindigkeit: x %6.2f"
 #define MSGTR_OSDosd "OSD: %s"
-#define MSGTR_OSDSubBottom "unten"
-#define MSGTR_OSDSubCenter "mitte"
-#define MSGTR_OSDSubTop "oben"
+
+// property values
+#define MSGTR_Enabled "aktiviert"
+#define MSGTR_EnabledEdl "aktiviert (edl)"
+#define MSGTR_Disabled "deaktiviert"
+#define MSGTR_HardFrameDrop "hart"
+#define MSGTR_Unknown "unbekannt"
+#define MSGTR_Bottom "unten"
+#define MSGTR_Center "mittig"
+#define MSGTR_Top "oben"
+
+// osd bar names
+#define MSGTR_Volume "Lautstrke"
+#define MSGTR_Panscan "Panscan"
+#define MSGTR_Gamma "Gamma"
+#define MSGTR_Brightness "Helligkeit"
+#define MSGTR_Contrast "Kontrast"
+#define MSGTR_Saturation "Sttigung"
+#define MSGTR_Hue "Farbton"
+
+// property state
+#define MSGTR_MuteStatus "Stumm: %s"
+#define MSGTR_AVDelayStatus "A/V-Verzgerung: %s"
+#define MSGTR_OnTopStatus "Immer im Vordergrund: %s"
+#define MSGTR_RootwinStatus "Anzeige auf dem Desktop: %s"
+#define MSGTR_BorderStatus "Rahmen: %s"
+#define MSGTR_FramedroppingStatus "Framedropping: %s"
+#define MSGTR_VSyncStatus "VSync: %s"
+#define MSGTR_SubSelectStatus "Untertitel: %s"
+#define MSGTR_SubPosStatus "Untertitelposition: %s/100"
+#define MSGTR_SubAlignStatus "Untertitelausrichtung: %s"
+#define MSGTR_SubDelayStatus "Untertitelverzgerung: %s"
+#define MSGTR_SubVisibleStatus "Untertitel: %s"
+#define MSGTR_SubForcedOnlyStatus "Erzwungene Untertitel: %s"
 
 // mencoder.c:
 
@@ -264,7 +280,8 @@ static char help_text[]=
 #define MSGTR_CBRPCMAudioSelected "CBR PCM Audio ausgewhlt.\n"
 #define MSGTR_MP3AudioSelected "MP3 Audio ausgewhlt.\n"
 #define MSGTR_CannotAllocateBytes "Konnte %d Bytes nicht reservieren.\n"
-#define MSGTR_SettingAudioDelay "Setze AUDIOVERZGERUNG auf %5.3f.\n"
+#define MSGTR_SettingAudioDelay "Setze Audioverzgerung auf %5.3f.\n"
+#define MSGTR_SettingVideoDelay "Setze Videoverzgerung auf %5.3f.\n"
 #define MSGTR_SettingAudioInputGain "Setze Audioeingangsverstrkung auf %f.\n"
 #define MSGTR_LamePresetEquals "\nPreset=%s\n\n"
 #define MSGTR_LimitingAudioPreload "Limitiere Audio-Preload auf 0.4s.\n"
@@ -498,6 +515,10 @@ static char help_text[]=
 #define MSGTR_UnknownProfile "Unbekanntes Profil '%s'.\n"
 #define MSGTR_Profile "Profil %s: %s\n"
 
+// m_property.c
+#define MSGTR_PropertyListHeader "\n Name                 Typ             Min        Max\n\n"
+#define MSGTR_TotalProperties "\nInsgesamt: %d Eigenschaften\n"
+
 // open.c, stream.c:
 #define MSGTR_CdDevNotfound "CD-ROM-Laufwerk '%s' nicht gefunden.\n"
 #define MSGTR_ErrTrackSelect "Fehler beim Auswhlen des VCD Tracks."
@@ -1058,6 +1079,7 @@ static char help_text[]=
 #define MSGTR_AO_OSS_CantUseGetospace "[AO OSS] audio_setup: Treiber untersttzt SNDCTL_DSP_GETOSPACE nicht :-(\n"
 #define MSGTR_AO_OSS_CantUseSelect "[AO OSS]\n  *** Dein Audiotreiber untersttzt select() NICHT***\nKompiliere MPlayer mit #undef HAVE_AUDIO_SELECT in der Datei config.h !\n\n"
 #define MSGTR_AO_OSS_CantReopen "[AO OSS]\nKritischer Fehler: *** KANN AUDIO-GERT NICHT ERNEUT FFNEN / ZURCKSETZEN *** %s\n"
+#define MSGTR_AO_OSS_UnknownUnsupportedFormat "[AO OSS] Unbekanntes/Nicht untersttztes OSS-Format: %x.\n"
 
 // ao_arts.c
 #define MSGTR_AO_ARTS_CantInit "[AO ARTS] %s\n"
@@ -1167,6 +1189,10 @@ static char help_text[]=
 #define MSGTR_AF_LADSPA_ErrControlBelow "%s: Input-Kontrolle #%d ist unterhalb der Grenze von %0.4f.\n"
 #define MSGTR_AF_LADSPA_ErrControlAbove "%s: Input-Kontrolle #%d ist berhalb der Grenze von %0.4f.\n"
 
+// format.c
+
+#define MSGTR_AF_FORMAT_UnknownFormat "unbekanntes-Format "
+
 // ========================== INPUT =========================================
 
 // joystick.c
@@ -1326,7 +1352,7 @@ static char help_text[]=
 #define MSGTR_MPDEMUX_AVIHDR_RegeneratingKeyfTableForMPG4V1 "Erstelle Keyframe-Tabelle fr MS-mpg4v1-Video neu...\n"
 #define MSGTR_MPDEMUX_AVIHDR_RegeneratingKeyfTableForDIVX3 "Erstelle Keyframe-Tabelle fr DIVX3-Video neu...\n"
 #define MSGTR_MPDEMUX_AVIHDR_RegeneratingKeyfTableForMPEG4 "Erstelle Keyframe-Tabelle fr MPEG4-Video neu...\n"
-#define MSGTR_MPDEMUX_AVIHDR_FoundWaveFmt "'wf' gefunden, %d Byte von %d.\n"
+#define MSGTR_MPDEMUX_AVIHDR_FoundWaveFmt "'wf' gefunden, %d Bytes von %d.\n"
 #define MSGTR_MPDEMUX_AVIHDR_FoundAVIV2Header "AVI: dmlh gefunden (size=%d) (total_frames=%d).\n"
 #define MSGTR_MPDEMUX_AVIHDR_ReadingIndexBlockChunksForFrames "Lese INDEX-Block, %d Blcke fr %d Frames (fpos=%"PRId64")\n"
 #define MSGTR_MPDEMUX_AVIHDR_AdditionalRIFFHdr "zustzlicher RIFF-Kopf...\n"
@@ -1416,3 +1442,116 @@ static char help_text[]=
 #define MSGTR_MPDEMUX_NW_NoPasswdProvidedTryingBlank "Kein Passwort angegeben, versuche leeres Passwort.\n"
 #define MSGTR_MPDEMUX_NW_ErrServerReturned "Server lieferte Fehler %d: %s\n"
 #define MSGTR_MPDEMUX_NW_CacheSizeSetTo "Setze Cache-Gre auf %d KByte.\n"
+
+// ========================== LIBMPMENU ===================================
+
+// libmenu/menu.c
+#define MSGTR_LIBMENU_SyntaxErrorAtLine "[MENU] Syntaxfehler bei Zeile: %d\n"
+#define MSGTR_LIBMENU_MenuDefinitionsNeedANameAttrib "[MENU] Mendefinitionen bentigen ein Namensattribut (Zeile %d)\n"
+#define MSGTR_LIBMENU_BadAttrib "[MENU] Schlechtes Attribut %s=%s in Men '%s' in Zeile %d\n"
+#define MSGTR_LIBMENU_UnknownMenuType "[MENU] Unbekannter Mentyp '%s' in Zeile %d\n"
+#define MSGTR_LIBMENU_CantOpenConfigFile "[MENU] Kann Men-Konfigurationsdatei nicht ffnen: %s\n"
+#define MSGTR_LIBMENU_ConfigFileIsTooBig "[MENU] Konfigurationsdatei ist zu gro (> %d KB)\n"
+#define MSGTR_LIBMENU_ConfigFileIsEmpty "[MENU] Konfigurationsdatei ist leer\n"
+#define MSGTR_LIBMENU_MenuNotFound "[MENU] Men %s nicht gefunden.\n"
+#define MSGTR_LIBMENU_MenuInitFailed "[MENU] Men '%s': Initialisierung fehlgeschlagen\n"
+#define MSGTR_LIBMENU_UnsupportedOutformat "[MENU] Nichtuntersttztes Ausgabeformat!!!!\n"
+
+// libmenu/menu_cmdlist.c
+#define MSGTR_LIBMENU_NoEntryFoundInTheMenuDefinition "[MENU] Kein Eintrag in der Mendefinition gefunden.\n"
+#define MSGTR_LIBMENU_ListMenuEntryDefinitionsNeedAName "[MENU] Definitionen fr Listenmeneintrge bentigen einen Namen (Zeile %d).\n"
+#define MSGTR_LIBMENU_ListMenuNeedsAnArgument "[MENU] Listenmen bentigt einen Parameter.\n"
+
+// libmenu/menu_console.c
+#define MSGTR_LIBMENU_WaitPidError "[MENU] Waitpid-Fehler: %s.\n"
+#define MSGTR_LIBMENU_SelectError "[MENU] Fehler bei der Auswahl.\n"
+#define MSGTR_LIBMENU_ReadErrorOnChilds "[MENU] Lesefehler bei child's: %s.\n"
+#define MSGTR_LIBMENU_ConsoleRun "[MENU] Konsolenaufruf: %s ...\n"
+#define MSGTR_LIBMENU_AChildIsAlreadyRunning "[MENU] Es luft schon ein Child.\n"
+#define MSGTR_LIBMENU_ForkFailed "[MENU] Fork-Fehler!!!\n"
+#define MSGTR_LIBMENU_WriteError "[MENU] Schreibfehler.\n"
+
+// libmenu/menu_filesel.c
+#define MSGTR_LIBMENU_OpendirError "[MENU] Opendir-Fehler: %s.\n"
+#define MSGTR_LIBMENU_ReallocError "[MENU] Realloc-Fehler: %s.\n"
+#define MSGTR_LIBMENU_MallocError "[MENU] Fehler bei der Speicherreservierung: %s.\n"
+#define MSGTR_LIBMENU_ReaddirError "[MENU] Readdir-Fehler: %s.\n"
+#define MSGTR_LIBMENU_CantOpenDirectory "[MENU] Kann Verzeichnis %s nicht ffnen\n"
+
+// libmenu/menu_param.c
+#define MSGTR_LIBMENU_NoEntryFoundInTheMenuDefinition "[MENU] Kein Eintrag in der Mendefinition gefunden.\n"
+#define MSGTR_LIBMENU_SubmenuDefinitionNeedAMenuAttribut "[MENU] Definition des Untermens bentit ein 'menu'-Attribut.\n"
+#define MSGTR_LIBMENU_PrefMenuEntryDefinitionsNeed "[MENU] Definitionen fr Konfigurationsmeneintrge bentigen ein\n       gltiges 'property'-Attribut (Zeile %d).\n"
+#define MSGTR_LIBMENU_PrefMenuNeedsAnArgument "[MENU] Konfigurationsmen bentigt einen Parameter.\n"
+
+// libmenu/menu_pt.c
+#define MSGTR_LIBMENU_CantfindTheTargetItem "[MENU] Kann Ziel-Item nicht finden ????\n"
+#define MSGTR_LIBMENU_FailedToBuildCommand "[MENU] Konnte folgenden Befehl nicht erstellen: %s.\n"
+
+// libmenu/menu_txt.c
+#define MSGTR_LIBMENU_MenuTxtNeedATxtFileName "[MENU] Textmen bentigt einen txt-Dateinamen (Parameterdatei).\n"
+#define MSGTR_LIBMENU_MenuTxtCantOpen "[MENU] ffnen nicht mglich: %s.\n"
+#define MSGTR_LIBMENU_WarningTooLongLineSplitting "[MENU] Warnung, Zeile zu lang. Zerlege sie.\n"
+#define MSGTR_LIBMENU_ParsedLines "[MENU] %d Zeilen eingelesen.\n"
+
+// libmenu/vf_menu.c
+#define MSGTR_LIBMENU_UnknownMenuCommand "[MENU] Unbekannter Befehl: '%s'.\n"
+#define MSGTR_LIBMENU_FailedToOpenMenu "[MENU] Konnte folgendes Men nicht ffnen: '%s'.\n"
+
+// ========================== LIBMPCODECS ===================================
+
+// libmpcodecs/ad_libdv.c
+#define MSGTR_MPCODECS_AudioFramesizeDiffers "[AD_LIBDV] Warnung! Audio-Framegre weicht ab! read=%d hdr=%d.\n"
+
+// libmpcodecs/vd_dmo.c vd_dshow.c vd_vfw.c
+#define MSGTR_MPCODECS_CouldntAllocateImageForCinepakCodec "[VD_DMO] Konnte Bild fr cinepak-Codec nicht allozieren.\n"
+
+// libmpcodecs/vd_ffmpeg.c
+#define MSGTR_MPCODECS_XVMCAcceleratedCodec "[VD_FFMPEG] XVMC-beschleunigter Codec.\n"
+#define MSGTR_MPCODECS_ArithmeticMeanOfQP "[VD_FFMPEG] Arithmetisches Mittel des QP: %2.4f, Harmonisches Mittel des QP: %2.4f\n"
+#define MSGTR_MPCODECS_DRIFailure "[VD_FFMPEG] DRI-Versagen.\n"
+#define MSGTR_MPCODECS_CouldntAllocateImageForCodec "[VD_FFMPEG] Konnte Bild fr Codec nicht allozieren.\n"
+#define MSGTR_MPCODECS_XVMCAcceleratedMPEG2 "[VD_FFMPEG] XVMC-beschleunigtes MPEG2.\n"
+#define MSGTR_MPCODECS_TryingPixfmt "[VD_FFMPEG] Versuche pixfmt=%d.\n"
+#define MSGTR_MPCODECS_McGetBufferShouldWorkOnlyWithXVMC "[VD_FFMPEG] Der mc_get_buffer sollte nur mit XVMC-Beschleunigung funktionieren!!"
+#define MSGTR_MPCODECS_UnexpectedInitVoError "[VD_FFMPEG] Unerwarteter init_vo-Fehler.\n"
+#define MSGTR_MPCODECS_UnrecoverableErrorRenderBuffersNotTaken "[VD_FFMPEG] Nicht zu behebender Fehler, Puffer zum Zeichnen nicht genommen.\n"
+#define MSGTR_MPCODECS_OnlyBuffersAllocatedByVoXvmcAllowed "[VD_FFMPEG] Nur von vo_xvmc allozierte Puffer erlaubt.\n"
+
+// libmpcodecs/ve_lavc.c
+#define MSGTR_MPCODECS_HighQualityEncodingSelected "[VE_LAVC] Encodierung in hoher Qualitt ausgewhlt (keine Echtzeit)!\n"
+#define MSGTR_MPCODECS_UsingConstantQscale "[VE_LAVC] Benutze konstanten Wert fr qscale = %f (VBR).\n"
+
+// libmpcodecs/ve_raw.c
+#define MSGTR_MPCODECS_OutputWithFourccNotSupported "[VE_RAW] Raw-Ausgabe mit fourcc [%x] nicht untersttzt!\n"
+#define MSGTR_MPCODECS_NoVfwCodecSpecified "[VE_RAW] Bentigten VfW-Codec nicht angegeben!!\n"
+
+// libmpcodecs/vf_crop.c
+#define MSGTR_MPCODECS_CropBadPositionWidthHeight "[CROP] Schlechte Position/Breite/Hhe - abgeschnittener Bereich\n       auerhalb des Originals!\n"
+
+// libmpcodecs/vf_cropdetect.c
+#define MSGTR_MPCODECS_CropArea "[CROP] Schnittbereich: X: %d..%d Y: %d..%d (-vf crop=%d:%d:%d:%d).\n"
+
+// libmpcodecs/vf_format.c, vf_palette.c, vf_noformat.c
+#define MSGTR_MPCODECS_UnknownFormatName "[VF_FORMAT] Unbekannter Formatname: '%s'.\n"
+
+// libmpcodecs/vf_framestep.c vf_noformat.c vf_palette.c vf_tile.c
+#define MSGTR_MPCODECS_ErrorParsingArgument "[VF_FRAMESTEP] Fehler beim Einlesen des Parameters.\n"
+
+// libmpcodecs/ve_vfw.c
+#define MSGTR_MPCODECS_CompressorType "Kompressionstyp: %.4lx\n"
+#define MSGTR_MPCODECS_CompressorSubtype "Kompressionssubtyp: %.4lx\n"
+#define MSGTR_MPCODECS_CompressorFlags "Kompressions-Flags: %lu, Version %lu, ICM-Version: %lu\n"
+#define MSGTR_MPCODECS_Flags "Flags:"
+#define MSGTR_MPCODECS_Quality " Qualitt"
+
+// libmpcodecs/vf_expand.c
+#define MSGTR_MPCODECS_FullDRNotPossible "Vollstndiges DR nicht mglich, versuche stattdessen SLICES!\n"
+#define MSGTR_MPCODECS_WarnNextFilterDoesntSupportSlices "WARNUNG! Nchster Filter untersttzt SLICES nicht, bereite dich auf sig11 vor...\n"
+#define MSGTR_MPCODECS_FunWhydowegetNULL "Wieso bekommen wir NULL??\n"
+
+// libmpcodecs/vf_fame.c
+#define MSGTR_MPCODECS_FatalCantOpenlibFAME "FATAL: Kann libFAME nicht ffnen!\n"
+
+// libmpcodecs/vf_test.c, vf_yuy2.c, vf_yvu9.c
+#define MSGTR_MPCODECS_WarnNextFilterDoesntSupport "%s vom nchsten Filter/vo nicht untersttzt :(\n"
\ No newline at end of file
