@@ -3,7 +3,7 @@
 //... Okay enough of the hw, now send the other two!
 //
 // Updated by: Gabrov <gabrov@freemail.hu>
-// Sync'ed with help_mp-en.h 1.221 (2006. 01. 30.)
+// Sync'ed with help_mp-en.h 1.237 (2006. 04. 02.)
 
 // ========================= MPlayer help ===========================
 
@@ -64,7 +64,6 @@ static char help_text[]=
 #define MSGTR_NoHomeDir "Nem tallom a HOME knyvtrat.\n"
 #define MSGTR_GetpathProblem "get_path(\"config\") problma\n"
 #define MSGTR_CreatingCfgFile "Konfigurcis fjl ltrehozsa: %s\n"
-#define MSGTR_InvalidAOdriver "Nem ltez audio meghajt: %s\nHasznld az '-ao help' opcit, hogy listt kapj a hasznlhat ao meghajtkrl.\n"
 #define MSGTR_CopyCodecsConf "(msold/linkeld az etc/codecs.conf fjlt ~/.mplayer/codecs.conf-ba)\n"
 #define MSGTR_BuiltinCodecsConf "Befordtott codecs.conf hasznlata.\n"
 #define MSGTR_CantLoadFont "Nem tudom betlteni a kvetkez fontot: %s\n"
@@ -202,30 +201,44 @@ static char help_text[]=
 
 #define MSGTR_OSDenabled "bekapcsolva"
 #define MSGTR_OSDdisabled "kikapcsolva"
-#define MSGTR_OSDnone "nincs"
-#define MSGTR_OSDunknown "ismeretlen"
-#define MSGTR_OSDDVDNAV "DVDNAV: %s"
 #define MSGTR_OSDChannel "Csatorna: %s"
-#define MSGTR_OSDSubtitles "Felirat: %s"
-#define MSGTR_OSDSubtitlesOff "Felirat: ki"
-#define MSGTR_OSDSubtitlesLanguage "Felirat: (%d) %s"
-#define MSGTR_OSDSub "Sub: (%d) %s%s"
 #define MSGTR_OSDSubDelay "Sub kss: %d ms"
-#define MSGTR_OSDSubPosition "Sub pozci: %d/100"
-#define MSGTR_OSDSubAlignment "Sub igazts: %s"
-#define MSGTR_OSDAVDelay "A-V kss: %d ms"
 #define MSGTR_OSDSpeed "Sebessg: x %6.2f"
-#define MSGTR_OSDStayOnTop "Mindig fell: %s"
-#define MSGTR_OSDRootwin "Fablak: %s"
-#define MSGTR_OSDBorder "Hatr: %s"
-#define MSGTR_OSDFramedrop "Kpkocka dobs: %s"
-#define MSGTR_OSDFramedropOn "be"
-#define MSGTR_OSDFramedropHard "ers"
-#define MSGTR_OSDFramedropOff "ki"
 #define MSGTR_OSDosd "OSD: %s"
-#define MSGTR_OSDSubBottom "alul"
-#define MSGTR_OSDSubCenter "kzpen"
-#define MSGTR_OSDSubTop "fent"
+
+// property values
+#define MSGTR_Enabled "bekapcsolva"
+#define MSGTR_EnabledEdl "bekapcsolva (edl)"
+#define MSGTR_Disabled "kikapcsolva"
+#define MSGTR_HardFrameDrop "ers"
+#define MSGTR_Unknown "ismeretlen"
+#define MSGTR_Bottom "alul"
+#define MSGTR_Center "kzpen"
+#define MSGTR_Top "fent"
+
+// osd bar names
+#define MSGTR_Volume "Hanger"
+#define MSGTR_Panscan "Panscan"
+#define MSGTR_Gamma "Gamma"
+#define MSGTR_Brightness "Fnyer"
+#define MSGTR_Contrast "Kontraszt"
+#define MSGTR_Saturation "Teltettsg"
+#define MSGTR_Hue "rnyalat"
+
+// property state
+#define MSGTR_MuteStatus "Nmt: %s"
+#define MSGTR_AVDelayStatus "A-V kss: %d ms"
+#define MSGTR_OnTopStatus "Mindig fell: %s"
+#define MSGTR_RootwinStatus "Fablak: %s"
+#define MSGTR_BorderStatus "Keret: %s"
+#define MSGTR_FramedroppingStatus "Kpkocka dobs: %s"
+#define MSGTR_VSyncStatus "VSync: %s"
+#define MSGTR_SubSelectStatus "Feliratok: %s"
+#define MSGTR_SubPosStatus "Felirat helye: %s/100"
+#define MSGTR_SubAlignStatus "Felirat illeszts: %s"
+#define MSGTR_SubDelayStatus "Felirat kss: %s"
+#define MSGTR_SubVisibleStatus "Feliratok: %s"
+#define MSGTR_SubForcedOnlyStatus "Csak knyszertett felirat: %s"
 
 // mencoder.c:
 
@@ -260,7 +273,8 @@ static char help_text[]=
 #define MSGTR_CBRPCMAudioSelected "CBR PCM audio kivlasztva\n"
 #define MSGTR_MP3AudioSelected "MP3 audio kivlasztva\n"
 #define MSGTR_CannotAllocateBytes "%d byte nem foglalhat le\n"
-#define MSGTR_SettingAudioDelay "Audi ksleltets belltsa: %5.3f\n"
+#define MSGTR_SettingAudioDelay "Audi ksleltets belltsa: %5.3fs\n"
+#define MSGTR_SettingVideoDelay "Vide ksleltets belltsa: %5.3fs\n"
 #define MSGTR_SettingAudioInputGain "Audio input erstse %f\n"
 #define MSGTR_LamePresetEquals "\npreset=%s\n\n"
 #define MSGTR_LimitingAudioPreload "Audio elretlts korltozva 0.4 mp-re\n"
@@ -491,6 +505,10 @@ static char help_text[]=
 #define MSGTR_UnknownProfile "Ismeretlen profil: '%s'.\n"
 #define MSGTR_Profile "Profil %s: %s\n"
 
+// m_property.c
+#define MSGTR_PropertyListHeader "\n Nv                  Tpus           Min        Max\n\n"
+#define MSGTR_TotalProperties "\nsszesen: %d tulajdonsg\n"
+
 // open.c, stream.c:
 #define MSGTR_CdDevNotfound "A CD-ROM meghajt (%s) nem tallhat!\n"
 #define MSGTR_ErrTrackSelect "Hiba a VCD-sv kivlasztsakor!"
@@ -1048,6 +1066,7 @@ static char help_text[]=
 #define MSGTR_AO_OSS_CantUseGetospace "[AO OSS] audio_setup: a vezrl nem tmogatja a SNDCTL_DSP_GETOSPACE-t :-(\n"
 #define MSGTR_AO_OSS_CantUseSelect "[AO OSS]\n   ***  Az audio vezrld NEM tmogatja a select() -et ***\n Fordtsd jra az MPlayer-t az #undef HAVE_AUDIO_SELECT sorral a config.h-ban!\n\n"
 #define MSGTR_AO_OSS_CantReopen "[AO OSS]\nVgzetes hiba: *** NEM LEHET JRA MEGNYITNI / BELLTANI AZ AUDIO ESZKZT *** %s\n"
+#define MSGTR_AO_OSS_UnknownUnsupportedFormat "[AO OSS] Ismeretlen/Nem tmogatott OSS formtum: %x.\n"
 
 // ao_arts.c
 #define MSGTR_AO_ARTS_CantInit "[AO ARTS] %s\n"
@@ -1157,6 +1176,10 @@ static char help_text[]=
 #define MSGTR_AF_LADSPA_ErrControlBelow "%s: A(z) #%d bemeneti vezrl a(z) %0.4f als hatr alatt van.\n"
 #define MSGTR_AF_LADSPA_ErrControlAbove "%s: A(z) #%d bemeneti vezrl a(z) %0.4f fels hatr felett van.\n"
 
+// format.c
+
+#define MSGTR_AF_FORMAT_UnknownFormat "ismeretlen formtum "
+
 // ========================== INPUT =========================================
 
 // joystick.c
@@ -1408,3 +1431,116 @@ static char help_text[]=
 #define MSGTR_MPDEMUX_NW_NoPasswdProvidedTryingBlank "Nincs jelsz megadva, res jelszt prblok.\n"
 #define MSGTR_MPDEMUX_NW_ErrServerReturned "Szerver vlasz %d: %s\n"
 #define MSGTR_MPDEMUX_NW_CacheSizeSetTo "Cache mret belltva %d KByte-ra\n"
+
+// ========================== LIBMPMENU ===================================
+
+// libmenu/menu.c
+#define MSGTR_LIBMENU_SyntaxErrorAtLine "[MENU] Szintaktikus hiba ebben a sorban: %d\n"
+#define MSGTR_LIBMENU_MenuDefinitionsNeedANameAttrib "[MENU] A men defincikhoz nevestett attribtum kell (%d. sor)\n"
+#define MSGTR_LIBMENU_BadAttrib "[MENU] Hibs attribtum %s=%s a(z) '%s' menben a(z) %d. sorban\n"
+#define MSGTR_LIBMENU_UnknownMenuType "[MENU] Ismeretlen men tpus: '%s' a(z) %d. sorban\n"
+#define MSGTR_LIBMENU_CantOpenConfigFile "[MENU] A men konfigurcis fjl nem nyithat meg: %s\n"
+#define MSGTR_LIBMENU_ConfigFileIsTooBig "[MENU] A konfigurcis fjl tl nagy (> %d KB)\n"
+#define MSGTR_LIBMENU_ConfigFileIsEmpty "[MENU] A konfigurcis fjl res\n"
+#define MSGTR_LIBMENU_MenuNotFound "[MENU] A(z) % men nem tallhat.\n"
+#define MSGTR_LIBMENU_MenuInitFailed "[MENU] '%s' men: init sikertelen\n"
+#define MSGTR_LIBMENU_UnsupportedOutformat "[MENU] Nem tmogatott kimeneti formtum!!!!\n"
+
+// libmenu/menu_cmdlist.c
+#define MSGTR_LIBMENU_NoEntryFoundInTheMenuDefinition "[MENU] Nem tallhat bejegyzs a men definciban.\n"
+#define MSGTR_LIBMENU_ListMenuEntryDefinitionsNeedAName "[MENU] A lista menelemek definciihoz kell egy nv (%d. sor).\n"
+#define MSGTR_LIBMENU_ListMenuNeedsAnArgument "[MENU] A lista menhz egy argumentum kell.\n"
+
+// libmenu/menu_console.c
+#define MSGTR_LIBMENU_WaitPidError "[MENU] Waitpid hiba: %s.\n"
+#define MSGTR_LIBMENU_SelectError "[MENU] Kivlasztsi hiba.\n"
+#define MSGTR_LIBMENU_ReadErrorOnChilds "[MENU] Olvassi hiba a gyerekben: %s.\n"
+#define MSGTR_LIBMENU_ConsoleRun "[MENU] Konzol futtats: %s ...\n"
+#define MSGTR_LIBMENU_AChildIsAlreadyRunning "[MENU] Egy gyermek mr fut.\n"
+#define MSGTR_LIBMENU_ForkFailed "[MENU] Fork sikertelen !!!\n"
+#define MSGTR_LIBMENU_WriteError "[MENU] rsi hiba.\n"
+
+// libmenu/menu_filesel.c
+#define MSGTR_LIBMENU_OpendirError "[MENU] Opendir hiba: %s.\n"
+#define MSGTR_LIBMENU_ReallocError "[MENU] Realloc hiba: %s.\n"
+#define MSGTR_LIBMENU_MallocError "[MENU] Memria foglalsi hiba: %s.\n"
+#define MSGTR_LIBMENU_ReaddirError "[MENU] Readdir hiba: %s.\n"
+#define MSGTR_LIBMENU_CantOpenDirectory "[MENU] A(z) %s knyvtr nem nyithat meg\n"
+
+// libmenu/menu_param.c
+#define MSGTR_LIBMENU_NoEntryFoundInTheMenuDefinition "[MENU] A men definciban nincs bejegyzs.\n"
+#define MSGTR_LIBMENU_SubmenuDefinitionNeedAMenuAttribut "[MENU] Az almen defincikba kell egy 'menu' attribtum.\n"
+#define MSGTR_LIBMENU_PrefMenuEntryDefinitionsNeed "[MENU] Pref men bejegyzs definciihoz egy j 'property' attribtum kell (%d. sor).\n"
+#define MSGTR_LIBMENU_PrefMenuNeedsAnArgument "[MENU] Pref menhz egy argumentum kell.\n"
+
+// libmenu/menu_pt.c
+#define MSGTR_LIBMENU_CantfindTheTargetItem "[MENU] Nem tallhat a cl elem ????\n"
+#define MSGTR_LIBMENU_FailedToBuildCommand "[MENU] Nem sikerlt a parancs felptse: %s.\n"
+
+// libmenu/menu_txt.c
+#define MSGTR_LIBMENU_MenuTxtNeedATxtFileName "[MENU] A szveges menhz egy txt fjl nv kell (param file).\n"
+#define MSGTR_LIBMENU_MenuTxtCantOpen "[MENU] Nem nyithat meg: %s.\n"
+#define MSGTR_LIBMENU_WarningTooLongLineSplitting "[MENU] Figyelem, tl hozz sor. Elvgom.\n"
+#define MSGTR_LIBMENU_ParsedLines "[MENU] %d sor rtelmezve.\n"
+
+// libmenu/vf_menu.c
+#define MSGTR_LIBMENU_UnknownMenuCommand "[MENU] Ismeretlen parancs: '%s'.\n"
+#define MSGTR_LIBMENU_FailedToOpenMenu "[MENU] Sikertelen a men megnyitsa: '%s'.\n"
+
+// ========================== LIBMPCODECS ===================================
+
+// libmpcodecs/ad_libdv.c
+#define MSGTR_MPCODECS_AudioFramesizeDiffers "[AD_LIBDV] Figyelem! Az audi keretmret klnbz! read=%d  hdr=%d.\n"
+
+// libmpcodecs/vd_dmo.c vd_dshow.c vd_vfw.c
+#define MSGTR_MPCODECS_CouldntAllocateImageForCinepakCodec "[VD_DMO] Nem foglalhat le a kp a cinepak codec-hez.\n"
+
+// libmpcodecs/vd_ffmpeg.c
+#define MSGTR_MPCODECS_XVMCAcceleratedCodec "[VD_FFMPEG] XVMC-vel gyorstott codec.\n"
+#define MSGTR_MPCODECS_ArithmeticMeanOfQP "[VD_FFMPEG] QP aritmetikus kzepe: %2.4f, QP harmonikus kzepe: %2.4f\n"
+#define MSGTR_MPCODECS_DRIFailure "[VD_FFMPEG] DRI hiba.\n"
+#define MSGTR_MPCODECS_CouldntAllocateImageForCodec "[VD_FFMPEG] Nem sikerlt a kp lefoglalsa a codec-hez.\n"
+#define MSGTR_MPCODECS_XVMCAcceleratedMPEG2 "[VD_FFMPEG] XVMC-vel gyorstott MPEG2.\n"
+#define MSGTR_MPCODECS_TryingPixfmt "[VD_FFMPEG] pixfmt=%d kiprblsa.\n"
+#define MSGTR_MPCODECS_McGetBufferShouldWorkOnlyWithXVMC "[VD_FFMPEG] Az mc_get_buffer csak XVMC gyorstssal mkdik!!"
+#define MSGTR_MPCODECS_UnexpectedInitVoError "[VD_FFMPEG] Vratlan init_vo hiba.\n"
+#define MSGTR_MPCODECS_UnrecoverableErrorRenderBuffersNotTaken "[VD_FFMPEG] Helyrehozhatatlan hiba, a render bufferek nincsenek meg.\n"
+#define MSGTR_MPCODECS_OnlyBuffersAllocatedByVoXvmcAllowed "[VD_FFMPEG] Csak a vo_xvmc ltal lefoglalt bufferek hasznlhatak.\n"
+
+// libmpcodecs/ve_lavc.c
+#define MSGTR_MPCODECS_HighQualityEncodingSelected "[VE_LAVC] Nagyon j minsg kdols kivlasztva (nem vals idej)!\n"
+#define MSGTR_MPCODECS_UsingConstantQscale "[VE_LAVC] Konstans qscale = %f (VBR) hasznlata.\n"
+
+// libmpcodecs/ve_raw.c
+#define MSGTR_MPCODECS_OutputWithFourccNotSupported "[VE_RAW] Nyers kimenet fourcc-vel [%x] nem tmogatott!\n"
+#define MSGTR_MPCODECS_NoVfwCodecSpecified "[VE_RAW] A krt VfW codec nincs megadva!!\n"
+
+// libmpcodecs/vf_crop.c
+#define MSGTR_MPCODECS_CropBadPositionWidthHeight "[CROP] Hibs pozci/szlessg/magassg - a levgott terlet az eredetin kvl van!\n"
+
+// libmpcodecs/vf_cropdetect.c
+#define MSGTR_MPCODECS_CropArea "[CROP] Vgsi terlet: X: %d..%d  Y: %d..%d  (-vf crop=%d:%d:%d:%d).\n"
+
+// libmpcodecs/vf_format.c, vf_palette.c, vf_noformat.c
+#define MSGTR_MPCODECS_UnknownFormatName "[VF_FORMAT] Ismeretlen formtumnv: '%s'.\n"
+
+// libmpcodecs/vf_framestep.c vf_noformat.c vf_palette.c vf_tile.c
+#define MSGTR_MPCODECS_ErrorParsingArgument "[VF_FRAMESTEP] Hiba az argumentum rtelmezsekor.\n"
+
+// libmpcodecs/ve_vfw.c
+#define MSGTR_MPCODECS_CompressorType "Tmrt tpusa: %.4lx\n"
+#define MSGTR_MPCODECS_CompressorSubtype "Tmrt altpusa: %.4lx\n"
+#define MSGTR_MPCODECS_CompressorFlags "Tmrt flag-jei: %lu, %lu verzi, ICM verzi: %lu\n"
+#define MSGTR_MPCODECS_Flags "Flag-ek:"
+#define MSGTR_MPCODECS_Quality " minsg"
+
+// libmpcodecs/vf_expand.c
+#define MSGTR_MPCODECS_FullDRNotPossible "A teljes DR nem lehetsges, inkbb SLICES-t prblok helyette!\n"
+#define MSGTR_MPCODECS_WarnNextFilterDoesntSupportSlices  "FIGYELEM! A kvetkez szr nem tmogatja a SLICES-t, kszlj a sig11-re...\n"
+#define MSGTR_MPCODECS_FunWhydowegetNULL "Mirt kaptunk itt NULL-t??\n"
+
+// libmpcodecs/vf_fame.c
+#define MSGTR_MPCODECS_FatalCantOpenlibFAME "VGZETES: a libFAME nem nyithat meg!\n"
+
+// libmpcodecs/vf_test.c, vf_yuy2.c, vf_yvu9.c
+#define MSGTR_MPCODECS_WarnNextFilterDoesntSupport "%s nem tmogatott a kvetkez szrben/vo-ban :(\n"
