@@ -1,5 +1,5 @@
 // FIXME: This needs to be redone properly.
-// Partially sync'ed with help_mp-en.h $Revision: 1.27 $
+// Partially sync'ed with help_mp-en.h $Revision: 1.28 $
 // This is a retranslation of the file by Bogdan Butnaru <bogdanb@fastmail.fm>,
 // based on the previous translation by Codre Adrian
 // <codreadrian@softhome.net> (address bounces).
@@ -69,8 +69,6 @@ static char help_text[]=
 #define MSGTR_GetpathProblem "get_path(\"config\") problem\n"
 #define MSGTR_CreatingCfgFile "Creez fiierul de configurare: %s\n"\
 	"ncearc '-vo help' pentru o list cu driveri video disponibili.\n"
-#define MSGTR_InvalidAOdriver "Numele driverului de ieire audio e greit: %s\n"\
-	"Folosete '-ao help' pentru lista cu driveri audio disponibili.\n"
 #define MSGTR_BuiltinCodecsConf "Folosesc 'codecs.conf' built-in.\n"
 #define MSGTR_CantLoadFont "Nu pot ncrca fontul: %s\n"
 #define MSGTR_CantLoadSub "Nu pot ncrca subtitrarea: %s\n"
