@@ -62,7 +62,6 @@ static char help_text[]=
 #define MSGTR_NoHomeDir "   HOME() \n"
 #define MSGTR_GetpathProblem "  get_path(\"config\")\n"
 #define MSGTR_CreatingCfgFile "  : %s\n"
-#define MSGTR_InvalidAOdriver "    : %s\n. '-ao help'     .\n"
 #define MSGTR_CopyCodecsConf "(/_ etc/codecs.conf (  MPlayer)  ~/.mplayer/codecs.conf)\n"
 #define MSGTR_BuiltinCodecsConf "  codecs.conf.\n"
 #define MSGTR_CantLoadFont "   : %s\n"
@@ -589,6 +588,7 @@ static char help_text[]=
 #define MSGTR_FontSelect " ..."
 #define MSGTR_PlayList ""
 #define MSGTR_Equalizer ""
+#define MSGTR_ConfigureEqualizer " "
 #define MSGTR_SkinBrowser " "
 #define MSGTR_Network " ..."
 #define MSGTR_Preferences ""
