@@ -60,8 +60,6 @@ static char help_text[]=
 #define MSGTR_NoHomeDir "Kan inte lokalisera $HOME-katalog.\n"
 #define MSGTR_GetpathProblem "get_path(\"config\") problem\n"
 #define MSGTR_CreatingCfgFile "Skapar konfigfil: %s\n"
-#define MSGTR_InvalidAOdriver "Ej godknd audio-ut-drivrutinsnamn: %s\n"\
-    "Anvnd '-ao help' fr att f en lista med tillgngliga audio-ut-drivrutiner.\n"
 #define MSGTR_CopyCodecsConf "(Kopiera/lnka etc/codecs.conf frn MPlayer's kllkod till ~/.mplayer/codecs.conf)\n"
 #define MSGTR_BuiltinCodecsConf "Anvnder standardinbyggd codecs.conf.\n"
 #define MSGTR_CantLoadFont "Kan inte ladda font: %s\n"
