@@ -4,6 +4,7 @@
 #include <math.h>
 #include <limits.h>
 #include <time.h>
+#include <assert.h>
 
 #if !defined(INFINITY) && defined(HUGE_VAL)
 #define INFINITY HUGE_VAL
@@ -74,7 +75,7 @@ static float lavc_param_vi_qoffset = 0.0;
 static int lavc_param_vmax_b_frames = 0;
 static int lavc_param_keyint = -1;
 static int lavc_param_vpass = 0;
-static int lavc_param_vrc_strategy = 2;
+static int lavc_param_vrc_strategy = 0;
 static int lavc_param_vb_strategy = 0;
 static int lavc_param_luma_elim_threshold = 0;
 static int lavc_param_chroma_elim_threshold = 0;
@@ -163,6 +164,7 @@ static int lavc_param_video_global_header= 0;
 char *lavc_param_acodec = "mp2";
 int lavc_param_atag = 0;
 int lavc_param_abitrate = 224;
+int lavc_param_audio_global_header= 0;
 
 #include "m_option.h"
 
@@ -316,6 +318,7 @@ m_option_t lavcopts_conf[]={
 	{"bidir_refine", &lavc_param_bidir_refine, CONF_TYPE_INT, CONF_RANGE, 0, 4, NULL},
 	{"sc_factor", &lavc_param_sc_factor, CONF_TYPE_INT, CONF_RANGE, 1, INT_MAX, NULL},
 	{"vglobal", &lavc_param_video_global_header, CONF_TYPE_INT, CONF_RANGE, 0, INT_MAX, NULL},
+	{"aglobal", &lavc_param_audio_global_header, CONF_TYPE_INT, CONF_RANGE, 0, INT_MAX, NULL},
 	{NULL, NULL, 0, 0, 0, 0, NULL}
 };
 #endif
@@ -336,7 +339,7 @@ struct vf_priv_s {
 #define FF_QP2LAMBDA 1
 #endif
 
-static int encode_frame(struct vf_instance_s* vf, AVFrame *pic);
+static int encode_frame(struct vf_instance_s* vf, AVFrame *pic, double pts);
 
 static int config(struct vf_instance_s* vf,
         int width, int height, int d_width, int d_height,
@@ -587,7 +590,7 @@ static int config(struct vf_instance_s* vf,
     lavc_venc_context->flags = 0;
     if (lavc_param_mb_decision)
     {
-	printf("High quality encoding selected (non real time)!\n");
+	mp_msg(MSGT_MENCODER, MSGL_INFO, MSGTR_MPCODECS_HighQualityEncodingSelected);
 #if LIBAVCODEC_BUILD < 4673
         lavc_venc_context->flags = CODEC_FLAG_HQ;
 #else
@@ -737,7 +740,7 @@ static int config(struct vf_instance_s* vf,
     /* fixed qscale :p */
     if (lavc_param_vqscale)
     {
-	printf("Using constant qscale = %f (VBR)\n", lavc_param_vqscale);
+	mp_msg(MSGT_MENCODER, MSGL_INFO, MSGTR_MPCODECS_UsingConstantQscale, lavc_param_vqscale);
 	lavc_venc_context->flags |= CODEC_FLAG_QSCALE;
 #if LIBAVCODEC_BUILD >= 4668
         lavc_venc_context->global_quality= 
@@ -780,7 +783,7 @@ static int control(struct vf_instance_s* vf, int request, void* data){
     switch(request){
         case VFCTRL_FLUSH_FRAMES:
             if(vf->priv->codec->capabilities & CODEC_CAP_DELAY)
-                while(encode_frame(vf, NULL) > 0);
+                while(encode_frame(vf, NULL, MP_NOPTS_VALUE) > 0);
             return CONTROL_TRUE;
         default:
             return CONTROL_UNKNOWN;
@@ -824,7 +827,7 @@ static double psnr(double d){
     return -10.0*log(d)/log(10);
 }
 
-static int put_image(struct vf_instance_s* vf, mp_image_t *mpi){
+static int put_image(struct vf_instance_s* vf, mp_image_t *mpi, double pts){
     AVFrame *pic= vf->priv->pic;
 
     pic->data[0]=mpi->planes[0];
@@ -846,22 +849,53 @@ static int put_image(struct vf_instance_s* vf, mp_image_t *mpi){
     }
 #endif
 
-    return (encode_frame(vf, pic) >= 0);
+    return (encode_frame(vf, pic, pts) >= 0);
 }
 
-static int encode_frame(struct vf_instance_s* vf, AVFrame *pic){
+static int encode_frame(struct vf_instance_s* vf, AVFrame *pic, double pts){
     const char pict_type_char[5]= {'?', 'I', 'P', 'B', 'S'};
     int out_size;
+    double dts;
 
+    if(pic){
+#if 0
+        pic->opaque= malloc(sizeof(pts));
+        memcpy(pic->opaque, &pts, sizeof(pts));
+#else
+        if(pts != MP_NOPTS_VALUE)
+            pic->pts= floor(pts / av_q2d(lavc_venc_context->time_base) + 0.5);
+        else
+            pic->pts= MP_NOPTS_VALUE;
+#endif
+    }
 	out_size = avcodec_encode_video(lavc_venc_context, mux_v->buffer, mux_v->buffer_size,
 	    pic);
 
+    if(pts != MP_NOPTS_VALUE) 
+        dts= pts - lavc_venc_context->delay * av_q2d(lavc_venc_context->time_base);
+    else
+        dts= MP_NOPTS_VALUE;
+#if 0
+    pts= lavc_venc_context->coded_frame->opaque ?
+           *(double*)lavc_venc_context->coded_frame->opaque
+         : MP_NOPTS_VALUE;
+#else
+    if(lavc_venc_context->coded_frame->pts != MP_NOPTS_VALUE)
+        pts= lavc_venc_context->coded_frame->pts * av_q2d(lavc_venc_context->time_base);
+    else
+        pts= MP_NOPTS_VALUE;
+    assert(MP_NOPTS_VALUE == AV_NOPTS_VALUE);
+#endif
+//fprintf(stderr, "ve_lavc %f/%f\n", dts, pts);
     if(out_size == 0) {
         ++mux_v->encoder_delay;
         return 0;
     }
            
-    muxer_write_chunk(mux_v,out_size,lavc_venc_context->coded_frame->key_frame?0x10:0, MP_NOPTS_VALUE, MP_NOPTS_VALUE);
+    muxer_write_chunk(mux_v,out_size,lavc_venc_context->coded_frame->key_frame?0x10:0, 
+                      dts, pts);
+    free(lavc_venc_context->coded_frame->opaque);
+    lavc_venc_context->coded_frame->opaque= NULL;
         
 #if LIBAVCODEC_BUILD >= 4643
     /* store psnr / pict size / type / qscale */
@@ -934,7 +968,7 @@ static void uninit(struct vf_instance_s* vf){
         double f= lavc_venc_context->width*lavc_venc_context->height*255.0*255.0;
         f*= lavc_venc_context->coded_frame->coded_picture_number;
         
-        printf("PSNR: Y:%2.2f, Cb:%2.2f, Cr:%2.2f, All:%2.2f\n",
+        mp_msg(MSGT_MENCODER, MSGL_INFO, "PSNR: Y:%2.2f, Cb:%2.2f, Cr:%2.2f, All:%2.2f\n",
             psnr(lavc_venc_context->error[0]/f),
             psnr(lavc_venc_context->error[1]*4/f),
             psnr(lavc_venc_context->error[2]*4/f),
