@@ -77,7 +77,7 @@ static int b8x8mv = 1;
 static int i8x8 = 1;
 static int i4x4 = 1;
 static int dct8 = 0;
-static int direct_pred = X264_DIRECT_PRED_TEMPORAL;
+static int direct_pred = X264_DIRECT_PRED_SPATIAL;
 static int weight_b = 0;
 static int chroma_me = 1;
 static int mixed_references = 0;
@@ -152,7 +152,7 @@ m_option_t x264encopts_conf[] = {
     {"noi8x8", &i8x8, CONF_TYPE_FLAG, 0, 0, 0, NULL},
     {"8x8dct", &dct8, CONF_TYPE_FLAG, 0, 0, 1, NULL},
     {"no8x8dct", &dct8, CONF_TYPE_FLAG, 0, 0, 0, NULL},
-    {"direct_pred", &direct_pred, CONF_TYPE_INT, CONF_RANGE, 0, 2, NULL},
+    {"direct_pred", &direct_pred, CONF_TYPE_INT, CONF_RANGE, 0, 3, NULL},
     {"weight_b", &weight_b, CONF_TYPE_FLAG, 0, 0, 1, NULL},
     {"noweight_b", &weight_b, CONF_TYPE_FLAG, 0, 1, 0, NULL},
     {"bime", &bidir_me, CONF_TYPE_FLAG, 0, 0, 1, NULL},
@@ -184,7 +184,7 @@ m_option_t x264encopts_conf[] = {
     {"qblur", &qblur, CONF_TYPE_FLOAT, CONF_RANGE, 0, 99, NULL},
     {"cplx_blur", &complexity_blur, CONF_TYPE_FLOAT, CONF_RANGE, 0, 999, NULL},
     {"zones", &zones, CONF_TYPE_STRING, 0, 0, 0, NULL},
-    {"subq", &subq, CONF_TYPE_INT, CONF_RANGE, 1, 6, NULL},
+    {"subq", &subq, CONF_TYPE_INT, CONF_RANGE, 1, 7, NULL},
     {"brdo", &bframe_rdo, CONF_TYPE_FLAG, 0, 0, 1, NULL},
     {"nobrdo", &bframe_rdo, CONF_TYPE_FLAG, 0, 0, 0, NULL},
     {"me", &me_method, CONF_TYPE_INT, CONF_RANGE, 1, 4, NULL},
@@ -221,7 +221,7 @@ static int parse_cqm(const char *str, uint8_t *cqm, int length,
     return 0;
 }
 
-static int put_image(struct vf_instance_s *vf, mp_image_t *mpi);
+static int put_image(struct vf_instance_s *vf, mp_image_t *mpi, double pts);
 static int encode_frame(struct vf_instance_s *vf, x264_picture_t *pic_in);
 
 static int config(struct vf_instance_s* vf, int width, int height, int d_width, int d_height, unsigned int flags, unsigned int outfmt) {
@@ -474,7 +474,7 @@ static int query_format(struct vf_instance_s* vf, unsigned int fmt)
     return 0;
 }
 
-static int put_image(struct vf_instance_s *vf, mp_image_t *mpi)
+static int put_image(struct vf_instance_s *vf, mp_image_t *mpi, double pts)
 {
     h264_module_t *mod=(h264_module_t*)vf->priv;
     int i;
