@@ -172,17 +172,17 @@ static vf_info_t* filter_list[]={
     &vf_info_delogo,
     &vf_info_remove_logo,
     &vf_info_hue,
-#ifdef USE_LIBAVCODEC
+#ifdef USE_LIBAVCODEC_DSPUTIL
     &vf_info_spp,
     &vf_info_uspp,
     &vf_info_fspp,
-    &vf_info_pp7,
+    &vf_info_qp,
 #endif
     &vf_info_yuvcsp,
     &vf_info_kerndeint,
     &vf_info_rgbtest,
 #ifdef USE_LIBAVCODEC
-    &vf_info_qp,
+    &vf_info_pp7,
 #endif
     &vf_info_phase,
     &vf_info_divtc,
@@ -318,7 +318,7 @@ mp_image_t* vf_get_image(vf_instance_t* vf, unsigned int outfmt, int mp_imgtype,
 		// need to re-allocate buffer memory:
 		free(mpi->planes[0]);
 		mpi->flags&=~MP_IMGFLAG_ALLOCATED;
-		printf("vf.c: have to REALLOCATE buffer memory :(\n");
+		mp_msg(MSGT_VFILTER,MSGL_V,"vf.c: have to REALLOCATE buffer memory :(\n");
 	    }
 //	} else {
 	} {
@@ -630,8 +630,8 @@ int vf_next_query_format(struct vf_instance_s* vf, unsigned int fmt){
     return flags;
 }
 
-int vf_next_put_image(struct vf_instance_s* vf,mp_image_t *mpi){
-    return vf->next->put_image(vf->next,mpi);
+int vf_next_put_image(struct vf_instance_s* vf,mp_image_t *mpi, double pts){
+    return vf->next->put_image(vf->next,mpi, pts);
 }
 
 void vf_next_draw_slice(struct vf_instance_s* vf,unsigned char** src, int * stride,int w, int h, int x, int y){
