@@ -519,7 +519,7 @@ static void get_image(struct vf_instance_s* vf, mp_image_t *mpi)
     mpi->flags|=MP_IMGFLAG_DIRECT;
 }
 
-static int put_image(struct vf_instance_s* vf, mp_image_t *mpi)
+static int put_image(struct vf_instance_s* vf, mp_image_t *mpi, double pts)
 {
     mp_image_t *dmpi;
     if(!(mpi->flags&MP_IMGFLAG_DIRECT)){
@@ -564,7 +564,7 @@ static int put_image(struct vf_instance_s* vf, mp_image_t *mpi)
 #ifdef HAVE_MMX2
     if(gCpuCaps.hasMMX2) asm volatile ("sfence\n\t");
 #endif
-    return vf_next_put_image(vf,dmpi);
+    return vf_next_put_image(vf,dmpi, pts);
 }
 
 static void uninit(struct vf_instance_s* vf)
