@@ -27,6 +27,9 @@ typedef struct da_priv {
   float last_pts;
 } da_priv_t;
 
+//! rather arbitrary value for maximum length of wav-format headers
+#define MAX_WAVHDR_LEN (1 * 1024 * 1024)
+
 // how many valid frames in a row we need before accepting as valid MP3
 #define MIN_MP3_HDRS 5
 
@@ -44,7 +47,7 @@ typedef struct mp3_hdr {
 } mp3_hdr_t;
 
 extern void free_sh_audio(sh_audio_t* sh);
-extern void print_wave_header(WAVEFORMATEX *h);
+extern void print_wave_header(WAVEFORMATEX *h, int verbose_level);
 
 int hr_mp3_seek = 0;
 
@@ -130,6 +133,150 @@ static mp3_hdr_t *add_mp3_hdr(mp3_hdr_t **list, off_t st_pos,
   return NULL;
 }
 
+#define FLAC_SIGNATURE_SIZE 4
+#define FLAC_STREAMINFO_SIZE 34
+#define FLAC_SEEKPOINT_SIZE 18
+
+enum {
+  FLAC_STREAMINFO = 0,
+  FLAC_PADDING,
+  FLAC_APPLICATION,
+  FLAC_SEEKTABLE,
+  FLAC_VORBIS_COMMENT,
+  FLAC_CUESHEET
+} flac_preamble_t;
+
+static void
+get_flac_metadata (demuxer_t* demuxer)
+{
+  uint8_t preamble[4];
+  unsigned int blk_len;
+  stream_t *s = NULL;
+
+  if (!demuxer)
+    return;
+
+  s = demuxer->stream;
+  if (!s)
+    return;
+  
+  /* file is qualified; skip over the signature bytes in the stream */
+  stream_seek (s, 4);
+
+  /* loop through the metadata blocks; use a do-while construct since there
+   * will always be 1 metadata block */
+  do {
+    int r;
+    
+    r = stream_read (s, (char *) preamble, FLAC_SIGNATURE_SIZE);
+    if (r != FLAC_SIGNATURE_SIZE)
+      return;
+
+    blk_len = (preamble[1] << 16) | (preamble[2] << 8) | (preamble[3] << 0);
+
+    switch (preamble[0] & 0x7F)
+    {
+    case FLAC_STREAMINFO:
+    {
+      if (blk_len != FLAC_STREAMINFO_SIZE)
+        return;
+
+      stream_skip (s, FLAC_STREAMINFO_SIZE);
+      break;
+    }
+
+    case FLAC_PADDING:
+      stream_skip (s, blk_len);
+      break;
+
+    case FLAC_APPLICATION:
+      stream_skip (s, blk_len);
+      break;
+
+    case FLAC_SEEKTABLE:
+    {
+      int seekpoint_count, i;
+
+      seekpoint_count = blk_len / FLAC_SEEKPOINT_SIZE;
+      for (i = 0; i < seekpoint_count; i++)
+        if (stream_skip (s, FLAC_SEEKPOINT_SIZE) != 1)
+          return;
+      break;
+    }
+
+    case FLAC_VORBIS_COMMENT:
+    {
+      /* For a description of the format please have a look at */
+      /* http://www.xiph.org/vorbis/doc/v-comment.html */
+
+      uint32_t length, comment_list_len;
+      char comments[blk_len];
+      void *ptr = comments;
+      char *comment;
+      int cn;
+      char c;
+
+      if (stream_read (s, comments, blk_len) == blk_len)
+      {
+        uint8_t *p = ptr;
+        length = p[0] + (p[1] << 8) + (p[2] << 16) + (p[3] << 24);
+        ptr += 4 + length;
+
+        p = ptr;
+        comment_list_len = p[0] + (p[1] << 8) + (p[2] << 16) + (p[3] << 24);
+        ptr += 4;
+
+        cn = 0;
+        for (; cn < comment_list_len; cn++)
+        {
+          p = ptr;
+          length = p[0] + (p[1] << 8) + (p[2] << 16) + (p[3] << 24);
+          ptr += 4;
+
+          comment = (char *) ptr;
+          c = comment[length];
+          comment[length] = 0;
+
+          if (!strncasecmp ("TITLE=", comment, 6) && (length - 6 > 0))
+            demux_info_add (demuxer, "Title", comment + 6);
+          else if (!strncasecmp ("ARTIST=", comment, 7) && (length - 7 > 0))
+            demux_info_add (demuxer, "Artist", comment + 7);
+          else if (!strncasecmp ("ALBUM=", comment, 6) && (length - 6 > 0))
+            demux_info_add (demuxer, "Album", comment + 6);
+          else if (!strncasecmp ("DATE=", comment, 5) && (length - 5 > 0))
+            demux_info_add (demuxer, "Year", comment + 5);
+          else if (!strncasecmp ("GENRE=", comment, 6) && (length - 6 > 0))
+            demux_info_add (demuxer, "Genre", comment + 6);
+          else if (!strncasecmp ("Comment=", comment, 8) && (length - 8 > 0))
+            demux_info_add (demuxer, "Comment", comment + 8);
+          else if (!strncasecmp ("TRACKNUMBER=", comment, 12)
+                   && (length - 12 > 0))
+          {
+            char buf[31];
+            buf[30] = '\0';
+            sprintf (buf, "%d", atoi (comment + 12));
+            demux_info_add(demuxer, "Track", buf);
+          }
+          comment[length] = c;
+
+          ptr += length;
+        }
+      }
+      break;
+    }
+
+    case FLAC_CUESHEET:
+      stream_skip (s, blk_len);
+      break;
+
+    default: 
+      /* 6-127 are presently reserved */
+      stream_skip (s, blk_len);
+      break;
+    }
+  } while ((preamble[0] & 0x80) == 0);
+}
+
 static int demux_audio_open(demuxer_t* demuxer) {
   stream_t *s;
   sh_audio_t* sh_audio;
@@ -185,7 +332,6 @@ static int demux_audio_open(demuxer_t* demuxer) {
       }
     } else if( hdr[0] == 'f' && hdr[1] == 'L' && hdr[2] == 'a' && hdr[3] == 'C' ) {
       frmt = fLaC;
-      stream_skip(s,-4);
       break;
     }
     // Add here some other audio format detection
@@ -268,6 +414,11 @@ static int demux_audio_open(demuxer_t* demuxer) {
       free_sh_audio(sh_audio);
       return 0;
     }
+    if(l > MAX_WAVHDR_LEN) {
+      mp_msg(MSGT_DEMUX,MSGL_ERR,"[demux_audio] Bad wav header length: too long (%d)!!!\n",l);
+      free_sh_audio(sh_audio);
+      return 0;
+    }
     sh_audio->wf = w = (WAVEFORMATEX*)malloc(l > sizeof(WAVEFORMATEX) ? l : sizeof(WAVEFORMATEX));
     w->wFormatTag = sh_audio->format = stream_read_word_le(s);
     w->nChannels = sh_audio->channels = stream_read_word_le(s);
@@ -294,7 +445,7 @@ static int demux_audio_open(demuxer_t* demuxer) {
      }
     }
 
-    if(verbose>0) print_wave_header(w);
+    if( mp_msg_test(MSGT_DEMUX,MSGL_V) ) print_wave_header(w, MSGL_V);
     if(l)
       stream_skip(s,l);
     do
@@ -312,7 +463,7 @@ static int demux_audio_open(demuxer_t* demuxer) {
 	unsigned char buf[16384]; // vlc uses 16384*4 (4 dts frames)
 	unsigned int i;
 	stream_read(s, buf, sizeof(buf));
-	for (i = 0; i < sizeof(buf); i += 2) {
+	for (i = 0; i < sizeof(buf) - 5; i += 2) {
 	    // DTS, 14 bit, LE
 	    if((buf[i] == 0xff) && (buf[i+1] == 0x1f) && (buf[i+2] == 0x00) &&
 	       (buf[i+3] == 0xe8) && ((buf[i+4] & 0xfe) == 0xf0) && (buf[i+5] == 0x07)) {
@@ -350,8 +501,24 @@ static int demux_audio_open(demuxer_t* demuxer) {
   } break;
   case fLaC:
 	    sh_audio->format = mmioFOURCC('f', 'L', 'a', 'C');
-	    demuxer->movi_start = stream_tell(s);
+	    demuxer->movi_start = stream_tell(s) - 4;
 	    demuxer->movi_end = s->end_pos;
+	    if (demuxer->movi_end > demuxer->movi_start) {
+	      // try to find out approx. bitrate
+	      int64_t size = demuxer->movi_end - demuxer->movi_start;
+	      int64_t num_samples = 0;
+	      int32_t srate = 0;
+	      stream_skip(s, 14);
+	      stream_read(s, (char *)&srate, 3);
+	      srate = be2me_32(srate) >> 12;
+	      stream_read(s, (char *)&num_samples, 5);
+	      num_samples = (be2me_64(num_samples) >> 24) & 0xfffffffff;
+	      if (num_samples && srate)
+	        sh_audio->i_bps = size * srate / num_samples;
+	    }
+	    if (sh_audio->i_bps < 1) // guess value to prevent crash
+	      sh_audio->i_bps = 64 * 1024;
+	    get_flac_metadata (demuxer);
 	    break;
   }
 
@@ -422,7 +589,10 @@ static int demux_audio_fill_buffer(demuxer_t *demuxer, demux_stream_t *ds) {
 	dp = new_demux_packet(l);
 	memcpy(dp->buffer,hdr,4);
 	if (stream_read(s,dp->buffer + 4,l-4) != l-4)
+	{
+	  free_demux_packet(dp);
 	  return 0;
+	}
 	priv->last_pts = priv->last_pts < 0 ? 0 : priv->last_pts + sh_audio->audio.dwScale/(float)sh_audio->samplerate;
 	break;
       }
