@@ -99,11 +99,14 @@ static int parse_psm(demuxer_t *demux, int len) {
   return 1;
 }
 
+// 500000 is a wild guess
+#define TIMESTAMP_PROBE_LEN 500000
+
 /// Open an mpg physical stream
 static demuxer_t* demux_mpg_open(demuxer_t* demuxer) {
   stream_t *s = demuxer->stream;
   off_t pos = stream_tell(s);
-  off_t end_seq_start = demuxer->movi_end-500000; // 500000 is a wild guess
+  off_t end_seq_start = demuxer->movi_end-TIMESTAMP_PROBE_LEN;
   float half_pts = 0.0;
   mpg_demuxer_t* mpg_d;
 
@@ -114,13 +117,18 @@ static demuxer_t* demux_mpg_open(demuxer_t* demuxer) {
   mpg_d->has_valid_timestamps = 1;
   mpg_d->num_a_streams = 0;
   if (demuxer->seekable && stream_tell(demuxer->stream) < end_seq_start) {
-    stream_seek(s,(pos + end_seq_start / 2));
+    off_t half_pos = pos + end_seq_start / 2;
+    stream_seek(s, half_pos);
     while ((!s->eof) && ds_fill_buffer(demuxer->video) && half_pts == 0.0) {
       half_pts = mpg_d->last_pts;
+      if (stream_tell(s) > half_pos + TIMESTAMP_PROBE_LEN)
+        break;
     }
     stream_seek(s,end_seq_start);
     while ((!s->eof) && ds_fill_buffer(demuxer->video)) {
       if (mpg_d->final_pts < mpg_d->last_pts) mpg_d->final_pts = mpg_d->last_pts;
+      if (stream_tell(s) > demuxer->movi_end)
+        break;
     }
     // educated guess about validity of timestamps
     if (mpg_d->final_pts > 3 * half_pts || mpg_d->final_pts < 1.5 * half_pts) {
@@ -144,9 +152,9 @@ static void demux_close_mpg(demuxer_t* demuxer) {
 }
 
 
-static unsigned int read_mpeg_timestamp(stream_t *s,int c){
+static unsigned long long read_mpeg_timestamp(stream_t *s,int c){
   int d,e;
-  unsigned int pts;
+  unsigned long long pts;
   d=stream_read_word(s);
   e=stream_read_word(s);
   if( ((c&1)!=1) || ((d&1)!=1) || ((e&1)!=1) ){
@@ -179,8 +187,8 @@ static int demux_mpg_read_packet(demuxer_t *demux,int id){
   int d;
   int len;
   unsigned char c=0;
-  unsigned int pts=0;
-  unsigned int dts=0;
+  unsigned long long pts=0;
+  unsigned long long dts=0;
   demux_stream_t *ds=NULL;
   mpg_demuxer_t *priv = (mpg_demuxer_t *) demux->priv;
   
@@ -559,7 +567,10 @@ static int demux_mpg_gxf_fill_buffer(demuxer_t *demux, demux_stream_t *ds) {
   pack = new_demux_packet(STREAM_BUFFER_SIZE);
   len = stream_read(demux->stream, pack->buffer, STREAM_BUFFER_SIZE);
   if (len <= 0)
+  {
+    free_demux_packet(pack);
     return 0;
+  }
   {
     register uint32_t state = (uint32_t)demux->priv;
     register int pos = -len;
@@ -749,6 +760,7 @@ void demux_seek_mpg(demuxer_t *demuxer,float rel_seek_secs,float audio_delay, in
 	      continue;
 	    }
           }
+	  if(!sh_video) break;
           i=sync_video_packet(d_video);
           if(sh_video->format == 0x10000004) {	//mpeg4
             if(i==0x1B6) {			//vop (frame) startcode
@@ -812,11 +824,15 @@ int demux_mpg_control(demuxer_t *demuxer,int cmd, void *arg){
 	    return DEMUXER_CTRL_DONTKNOW;
 
 	case DEMUXER_CTRL_SWITCH_AUDIO:
-            if (mpg_d && mpg_d->num_a_streams > 1 && demuxer->audio && demuxer->audio->sh) {
+            if(! (mpg_d && mpg_d->num_a_streams > 1 && demuxer->audio && demuxer->audio->sh))
+	      return DEMUXER_CTRL_NOTIMPL; 
+	    else {
               demux_stream_t *d_audio = demuxer->audio;
               sh_audio_t *sh_audio = d_audio->sh;
-              sh_audio_t *sh_a;
+              sh_audio_t *sh_a = sh_audio;
               int i;
+	      if(!sh_audio)
+	        return DEMUXER_CTRL_NOTIMPL;
               if (*((int*)arg) < 0)
               {
               for (i = 0; i < mpg_d->num_a_streams; i++) {
