@@ -159,10 +159,10 @@ static void dump_index(demuxer_t *demuxer, int stream_id)
     real_index_table_t *index;
     int i, entries;
 
-    if (verbose<=1)
+    if ( mp_msg_test(MSGT_DEMUX,MSGL_V) )
 	return;
     
-    if (stream_id > MAX_STREAMS)
+    if (stream_id >= MAX_STREAMS)
 	return;
 
     index = priv->index_table[stream_id];
@@ -1040,7 +1040,7 @@ got_video:
 	return 1;
     }
 
-if(stream_id<256){
+if(stream_id<MAX_STREAMS){
 
     if(demuxer->audio->id==-1 && demuxer->a_streams[stream_id]){
 	sh_audio_t *sh = demuxer->a_streams[stream_id];
@@ -1070,7 +1070,7 @@ discard:
   }//    goto loop;
 }
 
-extern void print_wave_header(WAVEFORMATEX *h);
+extern void print_wave_header(WAVEFORMATEX *h, int verbose_level);
 
 static demuxer_t* demux_open_real(demuxer_t* demuxer)
 {
@@ -1207,7 +1207,7 @@ static demuxer_t* demux_open_real(demuxer_t* demuxer)
 		int codec_pos;
 		int tmp;
 		int len;
-		char *descr, *mimet;
+		char *descr, *mimet = NULL;
 
 		stream_id = stream_read_word(demuxer->stream);
 		mp_msg(MSGT_DEMUX,MSGL_V,"Found new stream (id: %d)\n", stream_id);
@@ -1448,8 +1448,8 @@ static demuxer_t* demux_open_real(demuxer_t* demuxer)
 		    sh->wf->wFormatTag = sh->format;
 		    
 		    mp_msg(MSGT_DEMUX,MSGL_V,"audio fourcc: %.4s (%x)\n", (char *)&sh->format, sh->format);
-		    if (verbose > 0)
-		    print_wave_header(sh->wf);
+		    if ( mp_msg_test(MSGT_DEMUX,MSGL_V) )
+		    print_wave_header(sh->wf, MSGL_V);
 
 		    /* Select audio stream with highest bitrate if multirate file*/
 		    if (priv->is_multirate && ((demuxer->audio->id == -1) ||
