@@ -103,25 +103,25 @@ static URLProtocol mp_protocol = {
 
 static muxer_stream_t* lavf_new_stream(muxer_t *muxer, int type)
 {
-	muxer_priv_t *priv = (muxer_priv_t*) muxer->priv;
+	muxer_priv_t *priv = muxer->priv;
 	muxer_stream_t *stream;
 	muxer_stream_priv_t *spriv;
 	AVCodecContext *ctx;
 
-	if(!muxer || (type != MUXER_TYPE_VIDEO && type != MUXER_TYPE_AUDIO)) 
+	if(!muxer || (type != MUXER_TYPE_VIDEO && type != MUXER_TYPE_AUDIO))
 	{
 		mp_msg(MSGT_MUXER, MSGL_ERR, "UNKNOW TYPE %d\n", type);
 		return NULL;
 	}
 	
-	stream = (muxer_stream_t*) calloc(1, sizeof(muxer_stream_t));
+	stream = calloc(1, sizeof(muxer_stream_t));
 	if(!stream)
 	{
 		mp_msg(MSGT_MUXER, MSGL_ERR, "Could not alloc muxer_stream, EXIT\n");
 		return NULL;
 	}
 	muxer->streams[muxer->avih.dwStreams] = stream;
-	stream->b_buffer = (unsigned char *)malloc(2048);
+	stream->b_buffer = malloc(2048);
 	if(!stream->b_buffer)
 	{
 		mp_msg(MSGT_MUXER, MSGL_ERR, "Could not alloc b_buffer, EXIT\n");
@@ -132,7 +132,7 @@ static muxer_stream_t* lavf_new_stream(muxer_t *muxer, int type)
 	stream->b_buffer_ptr = 0;
 	stream->b_buffer_len = 0;
 	
-	spriv = (muxer_stream_priv_t*) calloc(1, sizeof(muxer_stream_priv_t));
+	spriv = calloc(1, sizeof(muxer_stream_priv_t));
 	if(!spriv) 
 	{
 		free(stream);
