@@ -327,11 +327,12 @@ static uint32_t calc_pack_hlen(muxer_priv_t *priv, muxer_headers_t *h);
 static int add_frame(muxer_headers_t *spriv, uint64_t idur, uint8_t *ptr, int len, uint8_t pt, uint32_t temp_ref);
 
 static muxer_stream_t* mpegfile_new_stream(muxer_t *muxer,int type){
-  muxer_priv_t *priv = (muxer_priv_t*) muxer->priv;
+  muxer_priv_t *priv;
   muxer_stream_t *s;
   muxer_headers_t *spriv;
 
   if (!muxer) return NULL;
+  priv = (muxer_priv_t*) muxer->priv;
   if(muxer->avih.dwStreams>=MUXER_MAX_STREAMS){
     mp_msg(MSGT_MUXER, MSGL_ERR, "Too many streams! increase MUXER_MAX_STREAMS !\n");
     return NULL;
@@ -1794,6 +1795,9 @@ static int soft_telecine(muxer_headers_t *vpriv, uint8_t *fps_ptr, uint8_t *se_p
 	uint8_t fps, tff, rff; 
 	int period; 
 	
+	if(! pce_ptr)
+		return 0;
+	
 	period = (vpriv->telecine == TELECINE_FILM2PAL) ? 12 : 4;
 	if(fps_ptr != NULL)
 	{
@@ -1829,8 +1833,6 @@ static int soft_telecine(muxer_headers_t *vpriv, uint8_t *fps_ptr, uint8_t *se_p
 	if(se_ptr)
 		se_ptr[1] &= 0xf7;
 	
-	if(! pce_ptr)
-		return 0;
 			
 	if(! vpriv->vframes)	//initial value of tff
 		vpriv->trf = (pce_ptr[3] >> 6) & 0x2;
@@ -2121,7 +2123,7 @@ static uint64_t fix_mp4_frame_duration(muxer_headers_t *vpriv)
 static size_t parse_mpeg4_video(muxer_stream_t *s, muxer_priv_t *priv, muxer_headers_t *vpriv, float fps, size_t len)
 {
 	size_t ptr = 0;
-	int64_t delta_pts;
+	int64_t delta_pts=0;
 	uint8_t pt;
 	
 	mp_msg(MSGT_MUXER, MSGL_DBG2,"parse_mpeg4_video, len=%u\n", (uint32_t) len);
@@ -2434,6 +2436,8 @@ static void mpegfile_write_chunk(muxer_stream_t *s,size_t len,unsigned int flags
  
   if(s->buffer == NULL)
   	return;
+  if(len == -1)
+	return;
   
   pts = 0;
   if (s->type == MUXER_TYPE_VIDEO) { // try to recognize frame type...
