@@ -37,7 +37,6 @@
 
 #include "version.h"
 
-extern int verbose;
 extern int stream_cache_size;
 
 extern int mp_input_check_interrupt(int time);
@@ -431,6 +430,7 @@ http_send_request( URL_t *url, off_t pos ) {
 		if( url->port==0 ) url->port = 8080;			// Default port for the proxy server
 		fd = connect2Server( url->hostname, url->port,1 );
 		url_free( server_url );
+		server_url = NULL;
 	} else {
 		if( server_url->port==0 ) server_url->port = 80;	// Default port for the web server
 		fd = connect2Server( server_url->hostname, server_url->port,1 );
@@ -451,6 +451,8 @@ http_send_request( URL_t *url, off_t pos ) {
 	return fd;
 err_out:
 	http_free(http_hdr);
+	if (proxy && server_url)
+		url_free(server_url);
 	return -1;
 }
 
