@@ -55,6 +55,7 @@ static GLuint osdatex[MAX_OSD_PARTS];
 static GLuint osdDispList[MAX_OSD_PARTS];
 //! How many parts the OSD currently consists of
 static int osdtexCnt;
+static int osd_color;
 
 static int use_aspect;
 static int use_yuv;
@@ -205,6 +206,8 @@ static void update_yuvconv(void) {
  */
 static void clearOSD(void) {
   int i;
+  if (!osdtexCnt)
+    return;
   glDeleteTextures(osdtexCnt, osdtex);
 #ifndef FAST_OSD
   glDeleteTextures(osdtexCnt, osdatex);
@@ -249,6 +252,7 @@ static int initGl(uint32_t d_width, uint32_t d_height) {
   glDisable(GL_CULL_FACE);
   glEnable(gl_target);
   glDrawBuffer(vo_doublebuffering?GL_BACK:GL_FRONT);
+  glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 
   mp_msg(MSGT_VO, MSGL_V, "[gl] Creating %dx%d texture...\n",
           texture_width, texture_height);
@@ -323,13 +327,7 @@ config(uint32_t width, uint32_t height, uint32_t d_width, uint32_t d_height, uin
   }
 #endif
 #ifdef GL_WIN32
-  o_dwidth = d_width;
-  o_dheight = d_height;
-  vo_fs = flags & VOFLAG_FULLSCREEN;
-  vo_vm = flags & VOFLAG_MODESWITCHING;
-  vo_dwidth = d_width;
-  vo_dheight = d_height;
-  if (!createRenderingContext())
+  if (!vo_w32_config(d_width, d_height, flags))
     return -1;
 #else
   if (WinID >= 0) {
@@ -434,6 +432,11 @@ static void create_osd_texture(int x0, int y0, int w, int h,
   // initialize to 8 to avoid special-casing on alignment
   int sx = 8, sy = 8;
   GLint scale_type = (scaled_osd) ? GL_LINEAR : GL_NEAREST;
+
+  if (w <= 0 || h <= 0 || stride < w) {
+    mp_msg(MSGT_VO, MSGL_V, "Invalid dimensions OSD for part!\n");
+    return;
+  }
   texSize(w, h, &sx, &sy);
 
   if (osdtexCnt >= MAX_OSD_PARTS) {
@@ -457,7 +460,7 @@ static void create_osd_texture(int x0, int y0, int w, int h,
   char *tmp = (char *)malloc(stride * h);
   // convert alpha from weird MPlayer scale.
   // in-place is not possible since it is reused for future OSDs
-  for (i = h * stride - 1; i; i--)
+  for (i = h * stride - 1; i > 0; i--)
     tmp[i] = srca[i] - 1;
   glUploadTex(gl_target, GL_ALPHA, GL_UNSIGNED_BYTE, tmp, stride,
               0, 0, w, h, 0);
@@ -522,6 +525,7 @@ flip_page(void)
     glOrtho(0, vo_dwidth, vo_dheight, 0, -1, 1);
     }
     glEnable(GL_BLEND);
+    glColor4ub((osd_color >> 16) & 0xff, (osd_color >> 8) & 0xff, osd_color & 0xff, 0xff);
     // draw OSD
     glCallLists(osdtexCnt, GL_UNSIGNED_INT, osdDispList);
     // set rendering parameters back to defaults
@@ -683,6 +687,7 @@ static opt_t subopts[] = {
   {"customprog",   OPT_ARG_MSTRZ,&custom_prog,  NULL},
   {"customtex",    OPT_ARG_MSTRZ,&custom_tex,   NULL},
   {"customtlin",   OPT_ARG_BOOL, &custom_tlin,  NULL},
+  {"osdcolor",     OPT_ARG_INT,  &osd_color,    NULL},
   {NULL}
 };
 
@@ -701,6 +706,7 @@ static int preinit(const char *arg)
     custom_prog = NULL;
     custom_tex = NULL;
     custom_tlin = 1;
+    osd_color = 0xffffff;
     if (subopt_parse(arg, subopts) != 0) {
       mp_msg(MSGT_VO, MSGL_FATAL,
               "\n-vo gl command line help:\n"
@@ -737,6 +743,8 @@ static int preinit(const char *arg)
               "    use a custom YUV conversion lookup texture\n"
               "  nocustomtlin\n"
               "    use GL_NEAREST scaling for customtex texture\n"
+              "  osdcolor=<0xRRGGBB>\n"
+              "    use the given color for the OSD\n"
               "\n" );
       return -1;
     }
