@@ -290,7 +290,7 @@ static int edl_seek(edl_record_ptr next_edl_record, demuxer_t* demuxer, demux_st
 static void mencoder_exit(int level, char *how)
 {
     if (how)
-	mp_msg(MSGT_MENCODER, MSGL_INFO, MSGTR_ExitingHow, mp_gettext(how));
+	mp_msg(MSGT_MENCODER, MSGL_INFO, MSGTR_ExitingHow, how);
     else
 	mp_msg(MSGT_MENCODER, MSGL_INFO, MSGTR_Exiting);
 
@@ -300,7 +300,7 @@ static void mencoder_exit(int level, char *how)
 void parse_cfgfiles( m_config_t* conf )
 {
   char *conffile;
-  if ((conffile = get_path("mencoder")) == NULL) {
+  if ((conffile = get_path("mencoder.conf")) == NULL) {
     mp_msg(MSGT_CPLAYER,MSGL_ERR,MSGTR_GetpathProblem);
   } else {
     if (m_config_parse_config_file(conf, conffile) < 0)
@@ -356,7 +356,7 @@ static void exit_sighandler(int x){
 static muxer_t* muxer=NULL;
 static FILE* muxer_f=NULL;
 
-extern void print_wave_header(WAVEFORMATEX *h);
+extern void print_wave_header(WAVEFORMATEX *h, int verbose_level);
 
 int main(int argc,char* argv[]){
 
@@ -722,7 +722,10 @@ if(!muxer) {
   mp_msg(MSGT_MENCODER, MSGL_FATAL, "Cannot initialize muxer.");
   mencoder_exit(1,NULL);
 }
+#if 0
+//disabled: it horrybly distorts filtered sound
 if(out_file_format == MUXER_TYPE_MPEG) audio_preload = 0;
+#endif
 
 muxer->audio_delay_fix = audio_delay_fix;
 
@@ -961,7 +964,7 @@ case ACODEC_COPY:
     break;
 }
 
-if (verbose>1) print_wave_header(mux_a->wf);
+if ( mp_msg_test(MSGT_MENCODER,MSGL_DBG2) ) print_wave_header(mux_a->wf, MSGL_DBG2);
 
 if (! ignore_start)
     muxer->audio_delay_fix += sh_audio->stream_delay;
@@ -1318,7 +1321,7 @@ case VCODEC_FRAMENO:
 default:
     // decode_video will callback down to ve_*.c encoders, through the video filters
     blit_frame=decode_video(sh_video,frame_data.start,frame_data.in_size,
-      skip_flag>0 && (!sh_video->vfilter || ((vf_instance_t *)sh_video->vfilter)->control(sh_video->vfilter, VFCTRL_SKIP_NEXT_FRAME, 0) != CONTROL_TRUE));
+      skip_flag>0 && (!sh_video->vfilter || ((vf_instance_t *)sh_video->vfilter)->control(sh_video->vfilter, VFCTRL_SKIP_NEXT_FRAME, 0) != CONTROL_TRUE), mux_v->timer);
     
     if (sh_video->vf_inited < 0) mencoder_exit(1, NULL);
     
@@ -1444,7 +1447,7 @@ if(sh_audio && !demuxer2){
 	    (int)demuxer->movi_end);
 #else
       if(!quiet) {
-	if(verbose>0) {
+	if( mp_msg_test(MSGT_AVSYNC,MSGL_V) ) {
 		mp_msg(MSGT_AVSYNC,MSGL_STATUS,"Pos:%6.1fs %6df (%2d%%) %3dfps Trem:%4dmin %3dmb  A-V:%5.3f [%d:%d] A/Vms %d/%d D/B/S %d/%d/%d \r",
 	    	mux_v->timer, decoded_frameno, (int)(p*100),
 	    	(t>1) ? (int)(decoded_frameno/t+0.5) : 0,
@@ -1736,7 +1739,7 @@ static int slowseek(float end_pts, demux_stream_t *d_video, demux_stream_t *d_au
 
         if (vfilter) {
             int softskip = (vfilter->control(vfilter, VFCTRL_SKIP_NEXT_FRAME, 0) == CONTROL_TRUE);
-            decode_video(sh_video, frame_data->start, frame_data->in_size, !softskip);
+            decode_video(sh_video, frame_data->start, frame_data->in_size, !softskip, MP_NOPTS_VALUE);
         }
 
 #ifdef USE_EDL
